# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["ModelOutputError", "Error"]


class Error(BaseModel):
    code: Optional[str] = None
    """error code"""

    message: Optional[str] = None
    """error message"""

    raw_output: Optional[str] = FieldInfo(alias="model_output", default=None)
    """raw output with errors generated by the model"""

    param: Optional[str] = None
    """error params"""

    type: Optional[str] = None
    """error type"""


class ModelOutputError(BaseModel):
    error: Error
